<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="pt_BR" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Iniciar torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Pular checagem de hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Criar subpasta</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Modo de Gerenciamento de Torrents:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Sem categoria</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Adicionar categoria...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Remover categoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Remover categorias não utilizadas</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Resumir torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausar torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Excluir torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nova Categoria</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editar categoria...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Sair do qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Somente um link por linha</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>A taxa limite de upload deve ser maior que 0 ou desabilitada.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>A taxa limite de download deve ser maior que 0 ou desabilitada.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>A taxa limite de upload alternativa deve ser maior que 0 ou desabilitada.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>A taxa limite de download alternativa deve ser maior que 0 ou desabilitada.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>O máximo de downloads ativos deve ser maior do que -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>O máximo de uploads ativos deve ser maior do que -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>O máximo de torrents ativos deve ser maior do que -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>O número máximo de conexões deve ser maior que 0 ou desabilitado.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>O número máximo de conexões por torrent deve ser maior que 0 ou desabilitado.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>O número máximo de slots de upload por torrent deve ser maior que 0 ou desabilitado.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Impossível salvar preferências do programa, qBittorrent provavelmente está inatingível.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent no Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>O limite da proporção de compartilhamento deve ser de 0 a 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>O limite do tempo de semeadura deve ser de 0 a 525600 minutos.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>A porta usada para conexão de entrada deve estar entre 1 e 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>A porta usada para a Interface Web deve estar entre 1 e 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Não é possível fazer login; qBittorrent provavelmente está inatingível.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nome de usuário ou senha inválidos.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuário</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autores Originais</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Fazer upload de torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Salvar arquivos no diretório:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Digite a pasta aqui</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mais informações'</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informações sobre certificados</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Definir local</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Taxa de limite de upload</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Limite de taxa de download</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Renomear torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Outro...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Segunda</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Terça</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Quarta</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Quinta</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Baixar torrents a partir de suas URLs ou links magnéticos</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Fazer upload de torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Deseja realmente excluir os torrents selecionados da lista de transferência?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Cliente qBittorrent não está alcançável</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>O número máximo de slots de upload por torrent deve ser maior que 0 ou desabilitado.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nome de categoria inválido:\nPor favor não use caracteres especiais no nome da categoria.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation> Não foi possível criar a categoria</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Taxa de limite de upload deve ser maior que 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Espaço livre: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>O temporizador de inatividade do torrent deve ser maior do que 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Gestão de Salvamento</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Taxa de limite de download deve ser maior que 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent foi encerrado</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opções...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Resumir</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Prioridade Mínima</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Prioridade Máxima</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Diminuir Prioridade</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Aumentar Prioridade</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra de Ferramentas Superior</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra de Status</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Velocidade na Barra de Título</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Doar!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Resume Todos</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pausar Todos</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Adicionar Arquivo Torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentação</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Adicionar Link Torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Velocidade limite global de upload</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Velocidade limite global de download</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Você tem certeza de que deseja fechar o qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Limites de velocidade alternativos</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Mecanismo de Busca</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrar lista de torrents...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Busca</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transferências</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexão</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interface Web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Idioma da interface de usuário:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Notificação por email quando completar o download</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Executar programa externo quando completar o torrent</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtro de IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Agendar para usar taxas de limite alternativas</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrents na Espera</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Semear torrents até que sua taxa de semeadura seja atingida</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Automaticamente adicionar estes trackers para novos downloads:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interface Web do Usuário (Controle remoto)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Endereço de IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domínios do servidor:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Usar HTTPS em vez de HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Ignorar autenticação para clientes no host local</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Ignorar autenticação para clientes em sub-redes IP da lista branca</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Atualizar meu nome de domínio dinâmico</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Manter torrents incompletos em:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copiar arquivos .torrent para:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copiar arquivos .torrent finalizados para:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Pré-alocar espaço em disco para todos os arquivos</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Adicionar extensão .!qB para arquivos incompletos</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Adicionar automaticamente torrents de:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servidor SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Este servidor espera por uma conexão segura (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocolo habilitado:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP e μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Porta de Escuta</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Porta usada para conexões de entrada:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Usar redirecionamento de porta UPnP / NAT-PMP do meu roteador</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Usar uma porta diferente a cada inicialização</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Limites de Conexão</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Número máximo de conexões por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Número máximo global de conexões:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Número máximo de slots de upload por torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Número máximo global de slots de upload:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Servidor Proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Nenhum)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Usar proxy para conexões de peer</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Desabilitar conexões não suportadas por proxy</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Usar proxy somente para torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Caminho do filtro (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Lista de endereços IP banidos manualmente...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Aplicar aos trackers</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Limite Global</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Upload:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Download:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Limites de Taxa Alternativos</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>De:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Até:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Quando:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Dias de semana</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Finais de semana</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Configurações de Limites de Taxa</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Aplicar taxa limite para transporte acima da carga</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Aplicar limite de taxa para protocolo µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacidade</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Habilitar DHT (rede decentralizada) para encontrar mais peers</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Habilitar Peer Exchange (PeX) para encontrar mais peers</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Habilitar Descoberta de Peer Local para encontrar mais peers</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Modo de encriptação:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Preferir encriptação</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Encriptação requerida</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Desabilitar encriptação</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Habilitar modo anônimo</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Máximo de downloads ativos:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Máximo de uploads ativos:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Máximo de torrents ativos:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Não contar torrents lentos nesses limites</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>LImite da Taxa de Compartilhamento</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Semear torrents até que sua taxa atinja</translation>
    </message>
    <message>
        <source>then</source>
        <translation>então</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pausá-los</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Removê-los</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Usar UPnP / NAT-PMP para redirecionar a porta do meu roteador</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificado:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Chave:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registrar</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nome do domínio:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parâmetros suportados (diferencia maiúsculas de minúsculas):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nome do torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Tags (separadas por vírgula)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Caminho de conteúdo (mesmo do caminho raiz para torrent multi arquivo)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Caminho raiz (caminho da subpasta do primeiro torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Caminho para salvar</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Número de arquivos</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Tamanho do torrent (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Tracker atual</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Informação de hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Dica: Coloque o parâmetro entre aspas para evitar que o texto seja cortado nos espaços em branco (ex.: "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>O nome de usuário para a interface Web deve conter mais que 3 caracteres.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>A senha de usuário da interface Web deve ser maior que 3 caracteres.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Habilitar proteção contra clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Habilitar proteção de Falsificação de Solicitação de Site Cruzado (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Excluir arquivos .torrent mais tarde </translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Limite da taxa de download:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Limite da taxa de upload:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Alterar senha atual</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Usar interface Web alternativa</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Caminho Padrão para Salvar:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>O local alternativo dos arquivos da interface Web não pode estar em branco.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Não iniciar o download automaticamente</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Alterar torrent para Modo Manual</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Quando a Categoria do Torrent for alterada:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Realocar torrents implicados</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Aplicar limite de taxa para peers na LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 significa ilimitado</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Realocar torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Quando o Caminho Padrão para Salvar for alterado:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Habilitar validação de cabeçalho do Host</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Quando o Caminho para Salvar da Categoria for alterado:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Criar subpasta para torrents com múltiplos arquivos</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Alterar torrents afetados para Modo Manual</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Local dos arquivos:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Temporizador de inatividade do torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Modo de Gerenciamento de Torrents Padrão:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Quando adicionar um torrent</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Bandeiras</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexão</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progresso</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Velocidade de download</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocidade de upload</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Baixado</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Subido</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevância</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Arquivos</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>País</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Máxima</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Rastreadores</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Peers</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Fontes HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Conteúdo</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Baixado:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferência</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Tempo Ativo:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Tempo Restante:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Subido:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Velocidade de Download:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Velocidade de Upload:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Peers:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limite de Download:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limite de Upload:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Gasto:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Conexões:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentário:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Proporção de compartilhamento:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Reanunciar em:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Última Vez Visto Completo:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Tamanho Total:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Pedaços:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Criado por:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Adicionado em:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Concluído em:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Criado em:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash do torrent:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Caminho para Salvar:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (possui %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 nesta sessão)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 máx.)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 média)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Limite de download:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Limite de upload:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Pasta Monitorada</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Substituir Local para Salvar</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Pasta monitorada</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Local padrão para salvar</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Estatísticas de usuário</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Estatísticas de cache</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Acertos do cache de leitura:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Tempo médio na fila:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Peers conectados:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Taxa de compartilhamento de todo o tempo:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Download de todo o tempo:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Perdas da sessão:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Upload de todo o tempo:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Tamanho total do buffer:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Estatísticas de performance</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Trabalhos de E/S na fila:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Sobrecarga do cache de escrita:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Sobrecarga do cache de leitura:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Tamanho total em fila:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nos</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Todos (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Baixando (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Enviando (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Completo (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Retomado (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pausado (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Ativo (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inativo (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Com erro (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Todos (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Baixando (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Enviando (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Completo (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pausado (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Retomado (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Ativos (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inativo (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Com erro (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Prioridade de download</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Faltando</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Disponibilidade</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Feito</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Peers</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Velocidade de download</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocidade de upload</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Taxa</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>ETA</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Adicionado em</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Completado em</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limite de download</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limite de upload</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Recebido</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Baixado na sessão</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Enviado na sessão</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Faltando</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tempo Ativo</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Caminho para salvar</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Completo</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limite da proporção</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Última Vez Visto Completo</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Última Atividade</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Tamanho Total</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensagem</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Baixado</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL do Tracker:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Atualizando...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Funcionando</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desabilitado</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Não contatado ainda</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Não funcionando</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copiar URL do tracker</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Adicionar novo tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Editar URL do tracker...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Editar Tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leeches</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Remover tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Diálogo de adição de Trackers</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista Trackers para adicionar (um por linha):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 atrás</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Alocando</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Movendo</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Enviando</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Enviando</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Espera</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Com erro</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Baixando</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Baixando metadados</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Verificando</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Arquivos Faltando</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Na fila de verificação</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Verificando dados de resumo</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Estacionado</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorias</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limitando Velocidade de Download de Torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limitando Velocidade de Upload de Torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Resumir</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forçar retomada</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Taxa de limite de compartilhamento...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limite de taxa de upload...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limite de taxa de download...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Mover para cima</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Mover para baixo</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Mover para o topo</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Mover para último</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Definir local...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Copiar nome</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Copiar hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Baixar primeiro a primeira e a última parte</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Gerenciamento Automático de Torrents</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nova...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Resetar</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioridade</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forçar re-checagem</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Copiar link magnético</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Modo super compartilhador</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Renomear...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Download em ordem sequencial</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Forçar reverificação</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nova Categoria</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Local</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Novo nome</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Definir local</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Forçar reanúncio</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Editar Categoria</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Caminho para salvar</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent Upload/Download limite</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Usar limite global de compartilhamento</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Não definir limite de compartilhamento</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Definir limite de compartilhamento para</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>taxa</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Um cliente BitTorrent avançado escrito em C++, baseado no toolkit Qt e libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Site:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Fórum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Rastreador de bug:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmação de exclusão</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Deletar também arquivos do disco</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Confirmação de exclusão - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Baixar de URLs</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixar</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Adicionar Links Torrent</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 minuto</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>O caminho para salvar está vazio</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Caminho do plugin:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL ou pasta local</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instalar plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Todos os plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Busca</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Plugins de busca...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Todas categorias</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Pesquisar em:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Copiar URL da página de descrição</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Ir para a página de descrição</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultados (exibindo</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Somente nomes de torrents</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Somente habilitados</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>de</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Em todos os lugares</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instalar novo plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Você pode obter novos plugins de busca aqui:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Plugins de pesquisa instalados:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Aviso: Certifique-se de observar as leis de copyright do seu país ao baixar torrents de qualquer um destes mecanismos de busca.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Verificar atualizações</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Plugins de pesquisa</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leechers</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Mecanismo de busca</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seeders</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitado</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
</context>
</TS>